@@ -1,15 +1,13 @@
 """Utility methods to access a package data."""
 
-from typing import Callable, Optional, cast
-
-import inspect
+from typing import Callable, cast
 
 from pathlib import Path
 
 import pkg_resources as pkg
 
 
-def filename_resolver(package: Optional[str] = None) -> Callable[[str], str]:
+def filename_resolver(package: str) -> Callable[[str], str]:
     """Create method to find data file name.
 
     Uses resource manager to handle all the cases of the deployment.
@@ -21,7 +19,7 @@ def filename_resolver(package: Optional[str] = None) -> Callable[[str], str]:
     Returns:
         callable which appends the argument to the package folder.
     """
-    package = _resolve_package(package)
+    # package = _resolve_package(package)
     resource_manager = pkg.ResourceManager()  # type: ignore
 
     def func(resource: str) -> str:
@@ -32,7 +30,7 @@ def filename_resolver(package: Optional[str] = None) -> Callable[[str], str]:
     return func
 
 
-def path_resolver(package: Optional[str] = None) -> Callable[[str], Path]:
+def path_resolver(package: str) -> Callable[[str], Path]:
     """Create method to find data path.
 
     Uses :py:func:`file_resolver`.
@@ -45,7 +43,7 @@ def path_resolver(package: Optional[str] = None) -> Callable[[str], Path]:
         callable which appends the argument to the package folder adt returns as Path.
     """
     # Note: we should define package here to have proper offset in callers stack.
-    package = _resolve_package(package)
+    # package = _resolve_package(package)
     resolver = filename_resolver(package)
 
     def func(resource: str) -> Path:
@@ -57,17 +55,24 @@ def path_resolver(package: Optional[str] = None) -> Callable[[str], Path]:
     return func
 
 
-class PackageNotFoundError(ValueError):
-    """Error when package is not specified and cannot be found."""
-
-    def __init__(self) -> None:
-        super().__init__("Cannot define package.")  # pragma: no cover
-
-
-def _resolve_package(package: Optional[str] = None) -> str:
-    if package is None:
-        module = inspect.getmodule(inspect.stack()[2][0])
-        if module is None:
-            raise PackageNotFoundError()  # pragma: no cover
-        package = module.__name__
-    return package
+# class PackageNotFoundError(ValueError):
+#     """Error when package is not specified and cannot be found."""
+#
+#     def __init__(self) -> None:
+#         super().__init__("Cannot define package.")  # pragma: no cover
+#
+#
+# def _resolve_package(
+#     package,
+# ):
+#     # No typing in this function,
+#     # otherwise typeguard decorates this and
+#     # the frame offset is to be found in a bit
+#     # more complex way.
+#     # ANN202 is ignored for this file (see .flake8)
+#     if package is None:
+#         module = inspect.getmodule(inspect.stack()[2][0])
+#         if module is None:
+#             raise PackageNotFoundError()  # pragma: no cover
+#         package = module.__name__
+#     return package
